# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from assisted_service_client.api_client import ApiClient


class AssistedServiceIsoApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_iso_and_upload_to_s3(self, assisted_service_iso_create_params, **kwargs):  # noqa: E501
        """create_iso_and_upload_to_s3  # noqa: E501

        Creates ISO for the user and uploads to S3.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_iso_and_upload_to_s3(assisted_service_iso_create_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssistedServiceIsoCreateParams assisted_service_iso_create_params: Parameters for creating an Assisted Service ISO. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_iso_and_upload_to_s3_with_http_info(assisted_service_iso_create_params, **kwargs)  # noqa: E501
        else:
            (data) = self.create_iso_and_upload_to_s3_with_http_info(assisted_service_iso_create_params, **kwargs)  # noqa: E501
            return data

    def create_iso_and_upload_to_s3_with_http_info(self, assisted_service_iso_create_params, **kwargs):  # noqa: E501
        """create_iso_and_upload_to_s3  # noqa: E501

        Creates ISO for the user and uploads to S3.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_iso_and_upload_to_s3_with_http_info(assisted_service_iso_create_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssistedServiceIsoCreateParams assisted_service_iso_create_params: Parameters for creating an Assisted Service ISO. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assisted_service_iso_create_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_iso_and_upload_to_s3" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assisted_service_iso_create_params' is set
        if ('assisted_service_iso_create_params' not in params or
                params['assisted_service_iso_create_params'] is None):
            raise ValueError("Missing the required parameter `assisted_service_iso_create_params` when calling `create_iso_and_upload_to_s3`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'assisted_service_iso_create_params' in params:
            body_params = params['assisted_service_iso_create_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['userAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assisted-service-iso', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_iso(self, **kwargs):  # noqa: E501
        """download_iso  # noqa: E501

        Downloads the Assisted Service ISO.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_iso(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_iso_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.download_iso_with_http_info(**kwargs)  # noqa: E501
            return data

    def download_iso_with_http_info(self, **kwargs):  # noqa: E501
        """download_iso  # noqa: E501

        Downloads the Assisted Service ISO.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_iso_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_iso" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['userAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assisted-service-iso/data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_presigned_for_assisted_service_iso(self, **kwargs):  # noqa: E501
        """get_presigned_for_assisted_service_iso  # noqa: E501

        Retrieves a pre-signed S3 URL for downloading assisted-service ISO.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_presigned_for_assisted_service_iso(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Presigned
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_presigned_for_assisted_service_iso_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_presigned_for_assisted_service_iso_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_presigned_for_assisted_service_iso_with_http_info(self, **kwargs):  # noqa: E501
        """get_presigned_for_assisted_service_iso  # noqa: E501

        Retrieves a pre-signed S3 URL for downloading assisted-service ISO.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_presigned_for_assisted_service_iso_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Presigned
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_presigned_for_assisted_service_iso" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['userAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assisted-service-iso/presigned', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Presigned',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
